@@ -9,7 +9,7 @@ default_config = {
     'INDEX_TITLE': _('Site administration'),
     'MENU_TITLE': _('Menu'),
     'SUPPORT_HREF': 'https://github.com/otto-torino/django-baton/issues',
-    'COPYRIGHT': 'copyright © 2017 <a href="https://www.otto.to.it">Otto srl</a>', # noqa
+    'COPYRIGHT': 'copyright © 2020 <a href="https://www.otto.to.it">Otto srl</a>', # noqa
     'POWERED_BY': '<a href="https://www.otto.to.it">Otto srl</a>',
     'CONFIRM_UNSAVED_CHANGES': True,
     'SHOW_MULTIPART_UPLOADING': True,
@@ -17,8 +17,11 @@ default_config = {
     'COLLAPSABLE_USER_AREA': False,
     'CHANGELIST_FILTERS_IN_MODAL': False,
     'CHANGELIST_FILTERS_ALWAYS_OPEN': False,
+    'CHANGELIST_FILTERS_FORM': False,
     'MENU_ALWAYS_COLLAPSED': False,
+    'MESSAGES_TOASTS': False,
     'GRAVATAR_DEFAULT_IMG': 'retro',
+    'LOGIN_SPLASH': None,
 }
 
 
